# BEGIN COPYRIGHT BLOCK
# Copyright (C) 2005 Red Hat, Inc.
# All rights reserved.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation version
# 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
# END COPYRIGHT BLOCK

%define coolkey_module "CoolKey PKCS #11 Module"
%define nssdb %{_sysconfdir}/pki/nssdb

Name: coolkey
Version: 1.1.0
Release: 17%{?dist}
Summary: CoolKey PKCS #11 module
License: LGPL
URL: http://directory.fedora.redhat.com/wiki/CoolKey
Source: coolkey-%{version}.tar.gz
Patch1: coolkey-cache-dir-move.patch
Patch2: coolkey-%{version}-gemalto.64k.patch
Patch3: coolkey-safenet.patch
Patch4: coolkey-cac.fix.patch
Patch5: coolkey-thread-fix-el5.patch
Patch6: coolkey-cac-rhl5.patch
Patch7: coolkey-piv-el5.patch
Patch8: coolkey-ecc-el5.patch
Patch9: coolkey-more-keys.patch
Group: System Environment/Libraries
BuildRoot:  %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: pcsc-lite-devel
BuildRequires: zlib-devel
BuildRequires: nss-devel
BuildRequires: autoconf
Requires: nss-tools
Requires: pcsc-lite 
Requires: pcsc-lite-libs
Requires: ifd-egate
Requires: ccid
Provides: CoolKey Openkey
Obsoletes: CoolKey Openkey
# 390 does not have libusb or smartCards
ExcludeArch: s390 s390x

%description
Linux Driver support for the CoolKey and CAC products. 

%package devel
Summary: CoolKey Applet libraries
Group: System Environment/Libraries
Requires: coolkey = %{version}-%{release}

%description devel
Linux Driver support to access the CoolKey applet.


%prep
%setup -q
%patch1 -b .cache.dir.move
%patch2 -b .gemalto.64k
%patch3 -b .safenet
%patch4 -b .cac.fix
%patch5 -b .coolkey-thread-fix
%patch6 -b .cac-rhl5
%patch7 -b .piv
%patch8 -b .ecc
%patch9 -b .more-keys

%build
autoconf
%configure --with-debug --disable-dependency-tracking --enable-pk11install
make %{?_smp_mflags} CFLAGS="$CFLAGS -fno-strict-aliasing" CXXFLAGS="$CXXFLAGS -fno-strict-aliasing"

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
ln -s pkcs11/libcoolkeypk11.so $RPM_BUILD_ROOT/%{_libdir}
mkdir -p $RPM_BUILD_ROOT/var/cache/coolkey

%clean
rm -rf $RPM_BUILD_ROOT

%post
/sbin/ldconfig
isThere=`modutil -rawlist -dbdir %{nssdb} | grep %{coolkey_module} || echo NO`
if [ "$isThere" == "NO" ]; then
   if [ -x %{_bindir}/pk11install ]; then
      pk11install -p %{nssdb} 'name=%{coolkey_module} library=libcoolkeypk11.so' ||:
   fi
fi


%postun
/sbin/ldconfig
if [ $1 -eq 0 ]; then
   modutil -delete %{coolkey_module} -dbdir %{nssdb} -force || :
fi


%files
%defattr(-,root,root,-)
%doc ChangeLog LICENSE 
%{_bindir}/pk11install
%{_libdir}/libcoolkeypk11.so
%{_libdir}/pkcs11/libcoolkeypk11.so
%{_libdir}/libckyapplet.so.1
%{_libdir}/libckyapplet.so.1.0.0
%attr(1777,root,root) /var/cache/coolkey

%files devel
%{_libdir}/libckyapplet.so
%{_libdir}/pkgconfig/libckyapplet.pc
%{_includedir}/*.h


%changelog
* Tue Apr 22 2014 Robert Relyea <rrelyea@redhat.com> - 1.1.0-17
- Expand the number of supported keys.

* Wed May 22 2013 Robert Relyea <rrelyea@redhat.com> - 1.1.0-16.1
- Fix ecc signing/derive

* Fri Apr 18 2013 Robert Relyea <rrelyea@redhat.com> - 1.1.0-16
- ecc update
- piv update

* Wed Jul 20 2010 Robert Relyea <rrelyea@redhat.com> - 1.1.0-15
- work with new piv-like CAC cards

* Mon Dec 21 2009 Jack Magne <jmagne@redhat.com> - 1.1.0-14
* Mon Dec 21 2009 Jack Magne <jmagne@redhat.com> - 1.1.0-13
- Appease rpmdiff for strict aliasing.

* Wed Dec 18 2009 Robert Relyea <rrelyea@redhat.com> - 1.1.0-12
- Fix threading issue. Coolkey will now work with non-threaded applications
- that don't link with libpthread.

* Tue Dec 08 2009 Jack Magne <jmagne@redhat.com>  - 1.1.0-11
- Resolves: #499976 - CAC cards can be incorrectly identified
- as a Coolkey.

* Mon Dec 07 2009 Jack Magne <jmagne@redhat.com>  - 1.1.0-10
- Resolves: #514299 - 2048 bit support.
- Resolves: #514298 - Support protocol T1 cards.

* Thu Jan 10 2008 Jack Magne <jmagne@redhat.com>  - 1.1.0-6
- Resolves: #385181 - Provide support for Gemalto 64K cards.

* Mon Sep 17 2007 Bob Relyea <rrelyea@redhat.com> - 1.1.0-5
- 1777 is not octal and does not set the correct bits should be 01777

* Tue Aug 13 2007 Bob Relyea <rrelyea@redhat.com> - 1.1.0-4
- fix cache location to be more secure

* Thu May 31 2007 Bob Relyea <rrelyea@redhat.com> - 1.1.0-3
- replace the install stuff

* Thu May 31 2007 Bob Relyea <rrelyea@redhat.com> - 1.1.0-2
- Back out RHEL-4 version of spec from CVS, add pcsc-lite-lib requires.

* Tue Feb 20 2007 Bob Relyea <rrelyea@redhat.com> - 1.1.0-1
- Pick up lates release.

* Wed Nov 1 2006 Bob Relyea <rrelyea@redhat.com> - 1.0.1-15
- Don't grab the CUID on cac's. Resting the card causes it to
- logout of other applications.

* Wed Nov 1 2006 Bob Relyea <rrelyea@redhat.com> - 1.0.1-14
- Shared memory directory needs to be writeable by all so
- coolkey can create caches for any user. (lack of caches
- show up in screen savers reactly slowly).

* Fri Oct 20 2006 Bob Relyea <rrelyea@redhat.com> - 1.0.1-13
- fix login hw race failures

* Fri Oct 20 2006 Bob Relyea <rrelyea@redhat.com> - 1.0.1-12
- add the dist flag

* Wed Oct 18 2006 Bob Relyea <rrelyea@redhat.com> - 1.0.1-11
- CAC cards sometimes need to reset before they can get their
- initial transaction (problem is noticed on insertion an removal)

* Tue Oct 17 2006 Jesse Keating <jkeating@redhat.com> - 1.0.1-10
- Only run pk11install if the binary is there (multilib fun)

* Mon Oct 09 2006 Bob Relyea <rrelyea@redhat.com> - 1.0.1-9
- use pk11install which does not require loading the module to install it.

* Mon Oct 09 2006 Bob Relyea <rrelyea@redhat.com> - 1.0.1-8
- pcscd must be running in order to add coolkey.

* Thu Oct 4 2006 Bob Relyea <rrelyea@redhat.com> - 1.0.1-7
- silence modutil warnings

* Thu Sep 30 2006 Bob Relyea <rrelyea@redhat.com> - 1.0.1-5
- install and uninstall coolkey in the system secmod.db

* Thu Sep 7 2006 Bob Relyea <rrelyea@redhat.com> - 1.0.1-4
- make the coolkey token caches persist over application calls.
- make a separate cache for each user.

* Sun Jul 16 2006 Florian La Roche <laroche@redhat.com> - 1.0.1-2
- fix excludearch line

* Mon Jul 10 2006 Bob Relyea <rrelyea@redhat.com> - 1.0.1-1
- Don't require pthread library in coolkey

* Mon Jul 10 2006 Bob Relyea <rrelyea@redhat.com> - 1.0.0-2
- remove s390 from the build

* Mon Jun 5 2006 Bob Relyea <rrelyea@redhat.com> - 1.0.0-1
- Initial revision for fedora
